[![check](https://github.com/retospect/optunacy/actions/workflows/check.yml/badge.svg)](https://github.com/retospect/optunacy/actions/workflows/check.yml)
# Optunacy - a better Optuna contour plotter

Plots Optuna contour plots trivially and with detailed mouseovers.

## Things to replace

- ```grep -ri word .``` will find the *word* in all the files
- ```find . | grep word``` will find the *word* in any filenames
- *wobble* - change to the internal package name you want to use 
- update the pyproject.py file to have your name and the right description. 
